@@ -35,9 +35,6 @@ traceroute_stop (Netinfo * netinfo)
 void
 traceroute_do (Netinfo * netinfo)
 {
-	GtkTextBuffer *buffer = NULL;
-	GtkTextIter start, end;
-	gushort count;
 	const gchar *host = NULL;
 	gchar *command = NULL;
 	gchar *program = NULL;
@@ -47,6 +44,11 @@ traceroute_do (Netinfo * netinfo)
         
 	g_return_if_fail (netinfo != NULL);
 
+	if (netinfo_validate_host (netinfo) == FALSE) {
+		netinfo_stop_process_command (netinfo);
+		return;
+	}
+
 	host = netinfo_get_host (netinfo);
 
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (netinfo->output));
@@ -54,23 +56,27 @@ traceroute_do (Netinfo * netinfo)
 		gtk_list_store_clear (GTK_LIST_STORE (model));
 	}
 
-/*	buffer =
-	    gtk_text_view_get_buffer (GTK_TEXT_VIEW (netinfo->output));
-
-	gtk_text_buffer_get_start_iter (buffer, &start);
-	gtk_text_buffer_get_end_iter (buffer, &end);
-
-	gtk_text_buffer_delete (buffer, &start, &end);*/
-
 	parent = gtk_widget_get_toplevel (netinfo->output);
 	
-	program = util_find_program_in_path ("tcptraceroute", NULL);
-	g_print ("tcptraceroute: %s\n", program);
-	if (program != NULL) {
-		program_name = g_strdup ("tcptraceroute");
-	} else {
-		program = util_find_program_dialog ("traceroute", parent);
-		program_name = g_strdup ("traceroute");
+	switch (netinfo_get_ip_version (netinfo))
+	{
+	case IPV4:
+		program = util_find_program_in_path ("tcptraceroute", NULL);
+		g_print ("tcptraceroute: %s\n", program);
+		if (program != NULL) {
+			program_name = g_strdup ("tcptraceroute");
+		} else {
+			program = util_find_program_dialog ("traceroute", parent);
+			program_name = g_strdup ("traceroute");
+		}
+		break;
+	case IPV6:
+		program = util_find_program_in_path ("traceroute6", NULL);
+		program_name = g_strdup ("traceroute6");
+		break;
+	default:
+		program = NULL;
+		break;
 	}
 
 	if (program != NULL) {
@@ -96,7 +102,6 @@ traceroute_foreach (Netinfo * netinfo, gchar * line, gint len,
 {
 	gchar *text_utf8;
 	gssize bytes_written;
-	GtkWidget *entry = NULL;
 	GtkTextBuffer *buffer = NULL;
 	GtkTextIter iter;
 
@@ -127,15 +132,12 @@ traceroute_foreach_with_tree (Netinfo * netinfo, gchar * line, gint len,
 	GtkTreePath *path;
 	GtkTreeModel *model;
 	GtkTreeView *widget;
-	const gchar *text;
 	gint count;
 	traceroute_data data;
 
 	g_return_if_fail (netinfo != NULL);
 	g_return_if_fail (line != NULL);
 
-    /* text = g_strchomp (line); */
-
 	widget = (GTK_TREE_VIEW (netinfo->output));
 
 	if (len > 0) {		/* there are data to show */
@@ -199,7 +201,6 @@ traceroute_foreach_with_tree (Netinfo * netinfo, gchar * line, gint len,
 	while (gtk_events_pending ()) {
 		  gtk_main_iteration_do (FALSE);
 	}
-	/* g_free (text); */
 }
 
 static gint
