@@ -35,3 +35,8 @@
 gint g_sprintf (gchar *str, gchar const *fmt, ...);
 
 #endif /* GLIB_MINOR_VERSION */
+
+GString * util_tree_model_to_string (GtkTreeView *treeview);
+gchar * util_find_program_in_path (const gchar * program, const gchar * path);
+gchar * util_find_program_dialog (gchar * program, GtkWidget *parent);
+gchar * util_legible_bytes (gchar *bytes);
